Crate pcode_ir

Crate pcode_ir 

P-code intermediate representation types.

Zero-dependency crate defining PcodeOp and Varnode — the types emitted by SLEIGH-generated instruction decoders.

Structs

Instruction
A decoded and lifted instruction.
Varnode
A triple (space, offset, size) identifying a storage location or constant.

Enums

AddressSpaceId
Identifies an address space in the P-code model.
DecodeError
Decode error returned when an instruction cannot be parsed.
PcodeOp
A single P-code operation.

Functions

count_reads
get_output
offset_unique_varnodes
Offset all Unique-space varnode offsets in an op by the given amount. Used to avoid unique offset collisions when combining P-code from multiple subtables.
optimize
Peephole-optimize a P-code op sequence:
reads_varnode
Check if a P-code op reads from a specific varnode.
visit_reads
writes_to