offset_unique_varnodes

Function offset_unique_varnodes 

pub fn offset_unique_varnodes(op: &mut PcodeOp, offset: u64)
Offset all Unique-space varnode offsets in an op by the given amount. Used to avoid unique offset collisions when combining P-code from multiple subtables.