Structs
- Instruction
- A decoded and lifted instruction.
- Varnode
- A triple (space, offset, size) identifying a storage location or constant.
Enums
- Address
Space Id - Identifies an address space in the P-code model.
- Decode
Error - Decode error returned when an instruction cannot be parsed.
- PcodeOp
- A single P-code operation.
Functions
- count_
reads - get_
output - offset_
unique_ varnodes - Offset all Unique-space varnode offsets in an op by the given amount. Used to avoid unique offset collisions when combining P-code from multiple subtables.
- optimize
- Peephole-optimize a P-code op sequence:
- reads_
varnode - Check if a P-code op reads from a specific varnode.
- visit_
reads - writes_
to